@@ -13,7 +13,8 @@ sub new {
     return $self;
 }
 
-sub set {
+sub set
+{
     trace();
     my $self = shift;
     $self->{greeting} = shift || 'bye!';
